/**
 ********************************************************************************
 * @file    ADS131M0x.h
 * @author  A. Guzman
 * @date    July 2, 2025
 * @brief
 ********************************************************************************
 */

#ifndef ADS131M0X_H
#define ADS131M0X_H

#include <stdint.h>
#include "ads131_reg_defs.h"

#ifdef __cplusplus
extern "C" {
#endif

ADS131M0x_StatusTypeDef ADS131M0x_ReadRegister(void *handle, uint8_t address, uint16_t *value);
ADS131M0x_StatusTypeDef ADS131M0x_WriteRegister(void *handle, uint8_t address, uint16_t value);

//ID
ADS131M0x_StatusTypeDef ADS131_GetID(void *handle, uint16_t *id);

//STATUS
ADS131M0x_StatusTypeDef ADS131_Status_GetLock(void *handle, ADS131M0x_STATUS_LOCK_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetFrameResync(void *handle, ADS131M0x_STATUS_F_RESYNC_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetRegMap(void *handle, ADS131M0x_STATUS_REG_MAP_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetCrcError(void *handle, ADS131M0x_STATUS_CRC_ERR_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetCrcType(void *handle, ADS131M0x_STATUS_CRC_TYPE_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetReset(void *handle, ADS131M0x_STATUS_RESET_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetWordLength(void *handle, ADS131M0x_STATUS_WLENGTH_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetDrdy3(void *handle, ADS131M0x_STATUS_DRDYx_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetDrdy2(void *handle, ADS131M0x_STATUS_DRDYx_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetDrdy1(void *handle, ADS131M0x_STATUS_DRDYx_t *mode);
ADS131M0x_StatusTypeDef ADS131_Status_GetDrdy0(void *handle, ADS131M0x_STATUS_DRDYx_t *mode);

//MODE
ADS131M0x_StatusTypeDef ADS131_Mode_GetRegCrcEn(void *handle, ADS131M0x_MODE_REG_CRC_EN_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetRegCrcEn(void *handle, ADS131M0x_MODE_REG_CRC_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetRXCrcEn(void *handle, ADS131M0x_MODE_RX_CRC_EN_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetRXCrcEn(void *handle, ADS131M0x_MODE_RX_CRC_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetCrcType(void *handle, ADS131M0x_MODE_CRC_TYPE_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetCrcType(void *handle, ADS131M0x_MODE_CRC_TYPE_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetReset(void *handle, ADS131M0x_MODE_RESET_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetReset(void *handle, ADS131M0x_MODE_RESET_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetWordLength(void *handle, ADS131M0x_MODE_WLENGTH_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetWordLength(void *handle, ADS131M0x_MODE_WLENGTH_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetTimeout(void *handle, ADS131M0x_MODE_TIMEOUT_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetTimeout(void *handle, ADS131M0x_MODE_TIMEOUT_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetDrdySelect(void *handle, ADS131M0x_MODE_DRDY_SEL_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetDrdySelect(void *handle, ADS131M0x_MODE_DRDY_SEL_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetDrdyHiZ(void *handle, ADS131M0x_MODE_DRDY_HiZ_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetDrdyHiZ(void *handle, ADS131M0x_MODE_DRDY_HiZ_t mode);
ADS131M0x_StatusTypeDef ADS131_Mode_GetDrdyFMT(void *handle, ADS131M0x_MODE_DRDY_FMT_t* mode);
ADS131M0x_StatusTypeDef ADS131_Mode_SetDrdyFMT(void *handle, ADS131M0x_MODE_DRDY_FMT_t mode);

//CLOCK
ADS131M0x_StatusTypeDef ADS131_Clock_GetCH3Enable(void *handle, ADS131M0x_CLOCK_CH3_EN_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetCH3Enable(void *handle, ADS131M0x_CLOCK_CH3_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetCH2Enable(void *handle, ADS131M0x_CLOCK_CH2_EN_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetCH2Enable(void *handle, ADS131M0x_CLOCK_CH2_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetCH1Enable(void *handle, ADS131M0x_CLOCK_CH1_EN_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetCH1Enable(void *handle, ADS131M0x_CLOCK_CH1_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetCH0Enable(void *handle, ADS131M0x_CLOCK_CH0_EN_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetCH0Enable(void *handle, ADS131M0x_CLOCK_CH0_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetTBM(void *handle, ADS131M0x_CLOCK_TBM_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetTBM(void *handle, ADS131M0x_CLOCK_TBM_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetOSR(void *handle, ADS131M0x_CLOCK_OSR_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetOSR(void *handle, ADS131M0x_CLOCK_OSR_t mode);
ADS131M0x_StatusTypeDef ADS131_Clock_GetPowerMode(void *handle, ADS131M0x_CLOCK_PWR_t *mode);
ADS131M0x_StatusTypeDef ADS131_Clock_SetPowerMode(void *handle, ADS131M0x_CLOCK_PWR_t mode);

//GAIN
ADS131M0x_StatusTypeDef ADS131_Gain_SetPGAGain(void *handle, uint8_t channel, uint16_t gain);
ADS131M0x_StatusTypeDef ADS131_Gain_GetPGAGain(void *handle, uint8_t channel, uint16_t *gain);

//CFG//
ADS131M0x_StatusTypeDef ADS131_CFG_GetGC_DLY(void *handle, ADS131M0x_CFG_GC_DLY_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetGC_DLY(void *handle, ADS131M0x_CFG_GC_DLY_t mode);
ADS131M0x_StatusTypeDef ADS131_CFG_GetGC_EN(void *handle, ADS131M0x_CFG_GC_EN_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetGC_EN(void *handle, ADS131M0x_CFG_GC_EN_t mode);
ADS131M0x_StatusTypeDef ADS131_CFG_GetCD_ALLCH(void *handle, ADS131M0x_CFG_CD_ALLCH_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetCD_ALLCH(void *handle, ADS131M0x_CFG_CD_ALLCH_t mode);
ADS131M0x_StatusTypeDef ADS131_CFG_GetCD_NUM(void *handle, ADS131M0x_CFG_CD_NUM_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetCD_NUM(void *handle, ADS131M0x_CFG_CD_NUM_t mode);
ADS131M0x_StatusTypeDef ADS131_CFG_GetCD_LEN(void *handle, ADS131M0x_CFG_CD_LEN_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetCD_LEN(void *handle, ADS131M0x_CFG_CD_LEN_t mode);
ADS131M0x_StatusTypeDef ADS131_CFG_GetCD_EN(void *handle, ADS131M0x_CFG_CD_EN_t* mode);
ADS131M0x_StatusTypeDef ADS131_CFG_SetCD_EN(void *handle, ADS131M0x_CFG_CD_EN_t mode);

// THRESHOLD
ADS131M0x_StatusTypeDef ADS131_Threshold_GetCD_TH_MSB(void *handle, ADS131M0x_THRSHLD_MSB_CD_TH_MSB_t *mode);
ADS131M0x_StatusTypeDef ADS131_Threshold_SetCD_TH_MSB(void *handle, ADS131M0x_THRSHLD_MSB_CD_TH_MSB_t mode);
ADS131M0x_StatusTypeDef ADS131_Threshold_GetCD_TH_LSB(void *handle, ADS131M0x_THRSHLD_LSB_CD_TH_LSB_t *mode);
ADS131M0x_StatusTypeDef ADS131_Threshold_SetCD_TH_LSB(void *handle, ADS131M0x_THRSHLD_LSB_CD_TH_LSB_t mode);
ADS131M0x_StatusTypeDef ADS131_Threshold_GetDCBLOCK(void *handle, ADS131M0x_THRSHLD_LSB_DCBLOCK_t *mode);
ADS131M0x_StatusTypeDef ADS131_Threshold_SetDCBLOCK(void *handle, ADS131M0x_THRSHLD_LSB_DCBLOCK_t mode);

// CHx Calibration
ADS131M0x_StatusTypeDef ADS131_Channel_GetOCAL(void *handle, uint8_t ch, uint32_t *ocal);
ADS131M0x_StatusTypeDef ADS131_Channel_SetOCAL(void *handle, uint8_t ch, uint32_t ocal);
ADS131M0x_StatusTypeDef ADS131_Channel_GetGCAL(void *handle, uint8_t ch, uint32_t *gcal);
ADS131M0x_StatusTypeDef ADS131_Channel_SetGCAL(void *handle, uint8_t ch, uint32_t gcal);

#ifdef __cplusplus
}
#endif

#endif // ADS131M0x_H
